@@ -3,7 +3,7 @@
 {-# OPTIONS_GHC -fno-warn-orphans #-}
 {-|
 Module:      TextShow.Control.Monad.ST
-Copyright:   (C) 2014-2015 Ryan Scott
+Copyright:   (C) 2014-2016 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -17,7 +17,7 @@ module TextShow.Control.Monad.ST (showbST) where
 
 import Control.Monad.ST (ST)
 import Data.Text.Lazy.Builder (Builder)
-import TextShow.Classes (TextShow(showb), TextShow1(..), TextShow2(..))
+import TextShow.Classes (TextShow(..), TextShow1(..), TextShow2(..))
 
 #include "inline.h"
 
@@ -29,13 +29,13 @@ showbST = showb
 {-# INLINE showbST #-}
 
 instance TextShow (ST s a) where
-    showb = showbPrecWith undefined 0
+    showb = liftShowbPrec undefined undefined 0
     INLINE_INST_FUN(showb)
 
 instance TextShow1 (ST s) where
-    showbPrecWith = showbPrecWith2 undefined
-    INLINE_INST_FUN(showbPrecWith)
+    liftShowbPrec = liftShowbPrec2 undefined undefined
+    INLINE_INST_FUN(liftShowbPrec)
 
 instance TextShow2 ST where
-    showbPrecWith2 _ _ _ _ = "<<ST action>>"
-    INLINE_INST_FUN(showbPrecWith2)
+    liftShowbPrec2 _ _ _ _ _ _ = "<<ST action>>"
+    INLINE_INST_FUN(liftShowbPrec2)
