@@ -3,7 +3,7 @@
 {-# OPTIONS_GHC -fno-warn-orphans #-}
 {-|
 Module:      TextShow.Functions
-Copyright:   (C) 2014-2015 Ryan Scott
+Copyright:   (C) 2014-2016 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -16,7 +16,7 @@ Optional 'TextShow', 'TextShow1', and 'TextShow2' instances for functions.
 module TextShow.Functions (showbFunction) where
 
 import Data.Text.Lazy.Builder (Builder)
-import TextShow.Classes (TextShow(showb, showbPrec), TextShow1(..), TextShow2(..))
+import TextShow.Classes (TextShow(..), TextShow1(..), TextShow2(..))
 
 #include "inline.h"
 
@@ -28,13 +28,13 @@ showbFunction = showb
 {-# INLINE showbFunction #-}
 
 instance TextShow (a -> b) where
-    showbPrec = showbPrecWith undefined
+    showbPrec = liftShowbPrec undefined undefined
     INLINE_INST_FUN(showbPrec)
 
 instance TextShow1 ((->) a) where
-    showbPrecWith = showbPrecWith2 undefined
-    INLINE_INST_FUN(showbPrecWith)
+    liftShowbPrec = liftShowbPrec2 undefined undefined
+    INLINE_INST_FUN(liftShowbPrec)
 
 instance TextShow2 (->) where
-    showbPrecWith2 _ _ _ _ = "<function>"
-    INLINE_INST_FUN(showbPrecWith2)
+    liftShowbPrec2 _ _ _ _ _ _ = "<function>"
+    INLINE_INST_FUN(liftShowbPrec2)
