@@ -1,4 +1,5 @@
 {-# LANGUAGE CPP                        #-}
+{-# LANGUAGE GADTs                      #-}
 {-# LANGUAGE GeneralizedNewtypeDeriving #-}
 {-# LANGUAGE KindSignatures             #-}
 {-# LANGUAGE StandaloneDeriving         #-}
@@ -12,12 +13,15 @@
 #endif
 
 #if __GLASGOW_HASKELL__ >= 706
+{-# LANGUAGE DataKinds                  #-}
 {-# LANGUAGE PolyKinds                  #-}
 #endif
 
+{-# OPTIONS_GHC -fno-warn-orphans #-}
+
 {-|
 Module:      Derived.PolyKinds
-Copyright:   (C) 2014-2015 Ryan Scott
+Copyright:   (C) 2014-2016 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -36,25 +40,32 @@ module Derived.PolyKinds (
 
 #include "generic.h"
 
+import           Data.Functor.Classes (Show1(..))
+
 import           Generics.Deriving.Base
 #if !defined(__LANGUAGE_DERIVE_GENERIC1__)
 import qualified Generics.Deriving.TH as Generics
 #endif
 
-import           GHC.Show (appPrec, appPrec1, showSpace)
-
 import           Test.QuickCheck (Arbitrary)
 
+import           Text.Show.Deriving (deriveShow1)
 import           TextShow (TextShow(..), TextShow1(..), TextShow2(..))
 import           TextShow.TH (deriveTextShow2, makeShowbPrec,
-                              makeShowbPrecWith, makeShowbPrecWith2)
+                              makeLiftShowbPrec, makeLiftShowbPrec2)
 
-import           TransformersCompat (Show1(..), Show2(..), showsUnaryWith)
+#if defined(NEW_FUNCTOR_CLASSES)
+import           Data.Functor.Classes (Show2(..))
+import           Text.Show.Deriving (deriveShow2, makeLiftShowsPrec, makeLiftShowsPrec2)
+#else
+import           Text.Show.Deriving (makeShowsPrec1)
+#endif
 
 -------------------------------------------------------------------------------
 
-newtype TyConCompose f g h j k a b =
-    TyConCompose (f (g (j a) (k a)) (h (j a) (k b)))
+-- NB: Don't use k as a type variable here! It'll trigger GHC Trac #12503.
+newtype TyConCompose f g h j p a b =
+    TyConCompose (f (g (j a) (p a)) (h (j a) (p b)))
 #if __GLASGOW_HASKELL__ >= 702
   deriving Generic
 #endif
@@ -73,7 +84,8 @@ deriving instance Show (f (g (j a) (k a)) (h (j a) (k b))) =>
 
 -------------------------------------------------------------------------------
 
-newtype TyConProxy a b = TyConProxy ()
+newtype TyConProxy a b where
+    TyConProxy :: () -> TyConProxy a b
   deriving ( Arbitrary
            , Show
 #if __GLASGOW_HASKELL__ >= 702
@@ -100,15 +112,7 @@ newtype TyConReallyHighKinds f a b c d e = TyConReallyHighKinds (f a b c d e)
 -------------------------------------------------------------------------------
 
 data family TyFamilyCompose
-#if __GLASGOW_HASKELL__ >= 708 && __GLASGOW_HASKELL__ < 710
-    (f :: k1 -> k2 -> *)
-    (g :: k3 -> k4 -> k1)
-    (h :: k3 -> k4 -> k2)
-    (j :: k5 -> k3)
-    (k :: k5 -> k4)
-    (a :: k5)
-    (b :: k5)
-#elif __GLASGOW_HASKELL__ >= 706
+#if __GLASGOW_HASKELL__ >= 706
     (t :: k1 -> k2 -> *)
     (u :: k3 -> k4 -> k1)
     (v :: k3 -> k4 -> k2)
@@ -148,16 +152,15 @@ deriving instance Show (f (g (j a) (k a)) (h (j a) (k b))) =>
 -------------------------------------------------------------------------------
 
 data family TyFamilyProxy
-#if __GLASGOW_HASKELL__ >= 708 && __GLASGOW_HASKELL__ < 710
-    (a :: k1) (b :: k2)
-#elif __GLASGOW_HASKELL__ >= 706
+#if __GLASGOW_HASKELL__ >= 706
     (x :: k1) (y :: k2)
 #else
     (x :: *)  (y :: *)
 #endif
     :: *
 
-newtype instance TyFamilyProxy a b = TyFamilyProxy ()
+newtype instance TyFamilyProxy a b where
+    TyFamilyProxy :: () -> TyFamilyProxy a b
   deriving ( Arbitrary
            , Show
 #if __GLASGOW_HASKELL__ >= 706
@@ -171,14 +174,7 @@ newtype instance TyFamilyProxy a b = TyFamilyProxy ()
 -------------------------------------------------------------------------------
 
 data family TyFamilyReallyHighKinds
-#if __GLASGOW_HASKELL__ >= 708 && __GLASGOW_HASKELL__ < 710
-    (f :: k1 -> k2 -> k3 -> k4 -> k5 -> *)
-    (a :: k1)
-    (b :: k2)
-    (c :: k3)
-    (d :: k4)
-    (e :: k5)
-#elif __GLASGOW_HASKELL__ >= 706
+#if __GLASGOW_HASKELL__ >= 706
     (g :: k1 -> k2 -> k3 -> k4 -> k5 -> *)
     (v :: k1)
     (w :: k2)
@@ -209,119 +205,68 @@ newtype instance TyFamilyReallyHighKinds f a b c d e =
 
 -------------------------------------------------------------------------------
 
+$(return [])
+
+-- TODO: Replace these with non-orphan instances
+$(deriveShow1 ''(,,,,))
+#if defined(NEW_FUNCTOR_CLASSES)
+$(deriveShow2 ''(,,,,))
+#endif
+
+#if defined(NEW_FUNCTOR_CLASSES)
 instance (Show1 (f (g (j a) (k a))), Show1 (h (j a)), Show1 k) =>
   Show1 (TyConCompose f g h j k a) where
-    showsPrecWith sp p (TyConCompose x) =
-        showsPrecCompose sp "TyConCompose" p x
+    liftShowsPrec = $(makeLiftShowsPrec ''TyConCompose)
 instance (Show2 f, Show2 g, Show2 h, Show1 j, Show1 k) =>
   Show2 (TyConCompose f g h j k) where
-    showsPrecWith2 sp1 sp2 p (TyConCompose x) =
-        showsPrecCompose2 sp1 sp2 "TyConCompose" p x
+    liftShowsPrec2 = $(makeLiftShowsPrec2 ''TyConCompose)
 
 instance Show1 (TyConProxy (a :: *)) where
-    showsPrecWith = showsPrecWith2 undefined
+    liftShowsPrec = $(makeLiftShowsPrec ''TyConProxy)
 instance Show2 TyConProxy where
-    showsPrecWith2 _ _ p (TyConProxy x) = showParen (p > appPrec) $
-          showString "TyConProxy "
-        . showsPrec appPrec1 x
+    liftShowsPrec2 = $(makeLiftShowsPrec2 ''TyConProxy)
 
 instance Show1 (f a b c d) => Show1 (TyConReallyHighKinds f a b c d) where
-    showsPrecWith sp p (TyConReallyHighKinds x) =
-        showsUnaryWith (showsPrecWith sp) "TyConReallyHighKinds" p x
+    liftShowsPrec = $(makeLiftShowsPrec ''TyConReallyHighKinds)
 instance Show2 (f a b c) => Show2 (TyConReallyHighKinds f a b c) where
-    showsPrecWith2 sp1 sp2 p (TyConReallyHighKinds x) =
-        showsUnaryWith (showsPrecWith2 sp1 sp2) "TyConReallyHighKinds" p x
+    liftShowsPrec2 = $(makeLiftShowsPrec2 ''TyConReallyHighKinds)
+#else
+instance (Functor (f (g (j a) (k a))), Functor (h (j a)),
+          Show1 (f (g (j a) (k a))), Show1 (h (j a)), Show1 k) =>
+  Show1 (TyConCompose f g h j k a) where
+    showsPrec1 = $(makeShowsPrec1 ''TyConCompose)
 
-instance (Show1 (f (g (j a) (k a))), Show1 (h (j a)), Show1 k) =>
-  Show1 (TyFamilyCompose f g h j k a) where
-    showsPrecWith sp p (TyFamilyCompose x) =
-        showsPrecCompose sp "TyFamilyCompose" p x
-instance (Show2 f, Show2 g, Show2 h, Show1 j, Show1 k) =>
-  Show2 (TyFamilyCompose f g h j k) where
-    showsPrecWith2 sp1 sp2 p (TyFamilyCompose x) =
-        showsPrecCompose2 sp1 sp2 "TyFamilyCompose" p x
+instance Show1 (TyConProxy (a :: *)) where
+    showsPrec1 = $(makeShowsPrec1 ''TyConProxy)
 
-instance Show1 (TyFamilyProxy (a :: *)) where
-    showsPrecWith = showsPrecWith2 undefined
-instance Show2 TyFamilyProxy where
-    showsPrecWith2 _ _ p (TyFamilyProxy x) = showParen (p > appPrec) $
-          showString "TyFamilyProxy "
-        . showsPrec appPrec1 x
-
-instance Show1 (f a b c d) => Show1 (TyFamilyReallyHighKinds f a b c d) where
-    showsPrecWith sp p (TyFamilyReallyHighKinds x) =
-        showsUnaryWith (showsPrecWith sp) "TyFamilyReallyHighKinds" p x
-instance Show2 (f a b c) => Show2 (TyFamilyReallyHighKinds f a b c) where
-    showsPrecWith2 sp1 sp2 p (TyFamilyReallyHighKinds x) =
-        showsUnaryWith (showsPrecWith2 sp1 sp2) "TyFamilyReallyHighKinds" p x
-
-showsPrecCompose :: (Show1 (f (g (j a) (k a))), Show1 (h (j a)), Show1 k)
-                 => (Int -> b -> ShowS) -> String
-                 -> Int -> f (g (j a) (k a)) (h (j a) (k b)) -> ShowS
-showsPrecCompose sp name p x = showParen (p > appPrec) $
-      showString name . showSpace
-    . showsPrecWith (showsPrecWith (showsPrecWith sp)) appPrec1 x
-
-showsPrecCompose2 :: (Show2 f, Show2 g, Show2 h, Show1 j, Show1 k)
-                  => (Int -> a -> ShowS) -> (Int -> b -> ShowS)
-                  -> String -> Int -> f (g (j a) (k a)) (h (j a) (k b)) -> ShowS
-showsPrecCompose2 sp1 sp2 name p x = showParen (p > appPrec) $
-      showString name . showSpace
-    . showsPrecWith2 (showsPrecWith2 (showsPrecWith sp1) (showsPrecWith sp1))
-                     (showsPrecWith2 (showsPrecWith sp1) (showsPrecWith sp2))
-                     appPrec1 x
-
--------------------------------------------------------------------------------
-
-$(return [])
+instance Show1 (f a b c d) => Show1 (TyConReallyHighKinds f a b c d) where
+    showsPrec1 = $(makeShowsPrec1 ''TyConReallyHighKinds)
+#endif
 
 instance TextShow (f (g (j a) (k a)) (h (j a) (k b))) =>
   TextShow (TyConCompose f g h j k a b) where
     showbPrec = $(makeShowbPrec ''TyConCompose)
 instance (TextShow1 (f (g (j a) (k a))), TextShow1 (h (j a)), TextShow1 k) =>
   TextShow1 (TyConCompose f g h j k a) where
-    showbPrecWith = $(makeShowbPrecWith ''TyConCompose)
+    liftShowbPrec = $(makeLiftShowbPrec ''TyConCompose)
 $(deriveTextShow2 ''TyConCompose)
 
 instance TextShow (TyConProxy a b) where
     showbPrec = $(makeShowbPrec ''TyConProxy)
 instance TextShow1 (TyConProxy a) where
-    showbPrecWith = $(makeShowbPrecWith ''TyConProxy)
+    liftShowbPrec = $(makeLiftShowbPrec ''TyConProxy)
 $(deriveTextShow2 ''TyConProxy)
 
 instance TextShow (f a b c d e) => TextShow (TyConReallyHighKinds f a b c d e) where
     showbPrec = $(makeShowbPrec ''TyConReallyHighKinds)
 instance TextShow1 (f a b c d) => TextShow1 (TyConReallyHighKinds f a b c d) where
-    showbPrecWith = $(makeShowbPrecWith ''TyConReallyHighKinds)
+    liftShowbPrec = $(makeLiftShowbPrec ''TyConReallyHighKinds)
 instance TextShow2 (f a b c) => TextShow2 (TyConReallyHighKinds f a b c) where
-    showbPrecWith2 = $(makeShowbPrecWith2 ''TyConReallyHighKinds)
-
-#if MIN_VERSION_template_haskell(2,7,0)
-instance TextShow (f (g (j a) (k a)) (h (j a) (k b))) =>
-  TextShow (TyFamilyCompose f g h j k a b) where
-    showbPrec = $(makeShowbPrec 'TyFamilyCompose)
-instance (TextShow1 (f (g (j a) (k a))), TextShow1 (h (j a)), TextShow1 k) =>
-  TextShow1 (TyFamilyCompose f g h j k a) where
-    showbPrecWith = $(makeShowbPrecWith 'TyFamilyCompose)
-$(deriveTextShow2 'TyFamilyCompose)
-
-instance TextShow (TyFamilyProxy a b) where
-    showbPrec = $(makeShowbPrec 'TyFamilyProxy)
-instance TextShow1 (TyFamilyProxy a) where
-    showbPrecWith = $(makeShowbPrecWith 'TyFamilyProxy)
-$(deriveTextShow2 'TyFamilyProxy)
-
-instance TextShow (f a b c d e) => TextShow (TyFamilyReallyHighKinds f a b c d e) where
-    showbPrec = $(makeShowbPrec 'TyFamilyReallyHighKinds)
-instance TextShow1 (f a b c d) => TextShow1 (TyFamilyReallyHighKinds f a b c d) where
-    showbPrecWith = $(makeShowbPrecWith 'TyFamilyReallyHighKinds)
-instance TextShow2 (f a b c) => TextShow2 (TyFamilyReallyHighKinds f a b c) where
-    showbPrecWith2 = $(makeShowbPrecWith2 'TyFamilyReallyHighKinds)
-#endif
+    liftShowbPrec2 = $(makeLiftShowbPrec2 ''TyConReallyHighKinds)
 
 #if !defined(__LANGUAGE_DERIVE_GENERIC1__)
-$(Generics.deriveMeta           ''TyConCompose)
-$(Generics.deriveRep1           ''TyConCompose)
+$(Generics.deriveMeta              ''TyConCompose)
+$(Generics.deriveRep1Options False ''TyConCompose)
 
 instance ( Functor (f (g (j a) (k a)))
          , Functor (h (j a))
@@ -343,9 +288,57 @@ $(Generics.deriveRepresentable0 ''TyConReallyHighKinds)
 #endif
 
 #if MIN_VERSION_template_haskell(2,7,0)
+# if !defined(NEW_FUNCTOR_CLASSES)
+instance (Functor (f (g (j a) (k a))), Functor (h (j a)),
+          Show1 (f (g (j a) (k a))), Show1 (h (j a)), Show1 k) =>
+  Show1 (TyFamilyCompose f g h j k a) where
+    showsPrec1 = $(makeShowsPrec1 'TyFamilyCompose)
+instance Show1 (TyFamilyProxy (a :: *)) where
+    showsPrec1 = $(makeShowsPrec1 'TyFamilyProxy)
+instance Show1 (f a b c d) => Show1 (TyFamilyReallyHighKinds f a b c d) where
+    showsPrec1 = $(makeShowsPrec1 'TyFamilyReallyHighKinds)
+# else
+instance (Show1 (f (g (j a) (k a))), Show1 (h (j a)), Show1 k) =>
+  Show1 (TyFamilyCompose f g h j k a) where
+    liftShowsPrec = $(makeLiftShowsPrec 'TyFamilyCompose)
+instance Show1 (TyFamilyProxy (a :: *)) where
+    liftShowsPrec = $(makeLiftShowsPrec 'TyFamilyProxy)
+instance Show1 (f a b c d) => Show1 (TyFamilyReallyHighKinds f a b c d) where
+    liftShowsPrec = $(makeLiftShowsPrec 'TyFamilyReallyHighKinds)
+
+instance (Show2 f, Show2 g, Show2 h, Show1 j, Show1 k) =>
+  Show2 (TyFamilyCompose f g h j k) where
+    liftShowsPrec2 = $(makeLiftShowsPrec2 'TyFamilyCompose)
+instance Show2 TyFamilyProxy where
+    liftShowsPrec2 = $(makeLiftShowsPrec2 'TyFamilyProxy)
+instance Show2 (f a b c) => Show2 (TyFamilyReallyHighKinds f a b c) where
+    liftShowsPrec2 = $(makeLiftShowsPrec2 'TyFamilyReallyHighKinds)
+# endif
+
+instance TextShow (f (g (j a) (k a)) (h (j a) (k b))) =>
+  TextShow (TyFamilyCompose f g h j k a b) where
+    showbPrec = $(makeShowbPrec 'TyFamilyCompose)
+instance (TextShow1 (f (g (j a) (k a))), TextShow1 (h (j a)), TextShow1 k) =>
+  TextShow1 (TyFamilyCompose f g h j k a) where
+    liftShowbPrec = $(makeLiftShowbPrec 'TyFamilyCompose)
+$(deriveTextShow2 'TyFamilyCompose)
+
+instance TextShow (TyFamilyProxy a b) where
+    showbPrec = $(makeShowbPrec 'TyFamilyProxy)
+instance TextShow1 (TyFamilyProxy a) where
+    liftShowbPrec = $(makeLiftShowbPrec 'TyFamilyProxy)
+$(deriveTextShow2 'TyFamilyProxy)
+
+instance TextShow (f a b c d e) => TextShow (TyFamilyReallyHighKinds f a b c d e) where
+    showbPrec = $(makeShowbPrec 'TyFamilyReallyHighKinds)
+instance TextShow1 (f a b c d) => TextShow1 (TyFamilyReallyHighKinds f a b c d) where
+    liftShowbPrec = $(makeLiftShowbPrec 'TyFamilyReallyHighKinds)
+instance TextShow2 (f a b c) => TextShow2 (TyFamilyReallyHighKinds f a b c) where
+    liftShowbPrec2 = $(makeLiftShowbPrec2 'TyFamilyReallyHighKinds)
+
 # if !defined(__LANGUAGE_DERIVE_GENERIC1__)
-$(Generics.deriveMeta           'TyFamilyCompose)
-$(Generics.deriveRep1           'TyFamilyCompose)
+$(Generics.deriveMeta              'TyFamilyCompose)
+$(Generics.deriveRep1Options False 'TyFamilyCompose)
 
 instance ( Functor (f (g (j a) (k a)))
          , Functor (h (j a))
