@@ -7,11 +7,15 @@
 {-# LANGUAGE DeriveGeneric              #-}
 #endif
 
+#if __GLASGOW_HASKELL__ >= 706
+{-# LANGUAGE DataKinds                  #-}
+#endif
+
 {-# OPTIONS_GHC -fno-warn-orphans #-}
 
 {-|
 Module:      Derived.TypeSynonyms
-Copyright:   (C) 2014-2015 Ryan Scott
+Copyright:   (C) 2014-2016 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -38,9 +42,12 @@ import           Prelude
 
 import           Test.QuickCheck (Arbitrary)
 
-import           TextShow.TH (deriveTextShow, deriveTextShow1, deriveTextShow2)
+import           Text.Show.Deriving (deriveShow1)
+#if defined(NEW_FUNCTOR_CLASSES)
+import           Text.Show.Deriving (deriveShow2)
+#endif
 
-import           TransformersCompat (Show1(..), Show2(..), showsUnaryWith)
+import           TextShow.TH (deriveTextShow, deriveTextShow1, deriveTextShow2)
 
 -------------------------------------------------------------------------------
 
@@ -52,14 +59,6 @@ type Flip f a b = f b a
 instance Functor ((,,,) a b c) where
     fmap f (a, b, c, d) = (a, b, c, f d)
 
-instance (Show a, Show b) => Show2 ((,,,) a b) where
-    showsPrecWith2 sp1 sp2 _ (a, b, c, d) =
-                          showChar '('
-        . showsPrec 0 a . showChar ','
-        . showsPrec 0 b . showChar ','
-        . sp1       0 c . showChar ','
-        . sp2       0 d . showChar ')'
-
 -------------------------------------------------------------------------------
 
 newtype TyCon a b = TyCon
@@ -80,12 +79,7 @@ newtype TyCon a b = TyCon
 
 -------------------------------------------------------------------------------
 
-data family TyFamily
-#if __GLASGOW_HASKELL__ >= 708 && __GLASGOW_HASKELL__ < 710
-                     a b :: *
-#else
-                     y z :: *
-#endif
+data family TyFamily y z :: *
 
 newtype instance TyFamily a b = TyFamily
     ( Id (FakeOut (Id a))
@@ -105,34 +99,21 @@ newtype instance TyFamily a b = TyFamily
 
 -------------------------------------------------------------------------------
 
-instance Show a => Show1 (TyCon a) where
-    showsPrecWith = showsPrecWith2 showsPrec
-instance Show2 TyCon where
-    showsPrecWith2 sp1 sp2 p (TyCon x) =
-        showsUnaryWith (showsPrecWith2 (showsPrecWith2 showsPrec sp1)
-                                       (showsPrecWith2 sp1       sp2)
-                       ) "TyCon" p x
+-- TODO: Replace these with non-orphan instances
+$(deriveShow1 ''(,,,))
+#if defined(NEW_FUNCTOR_CLASSES)
+$(deriveShow2 ''(,,,))
+#endif
 
-instance Show a => Show1 (TyFamily a) where
-    showsPrecWith = showsPrecWith2 showsPrec
-instance Show2 TyFamily where
-    showsPrecWith2 sp1 sp2 p (TyFamily x) =
-        showsUnaryWith (showsPrecWith2 (showsPrecWith2 showsPrec sp1)
-                                       (showsPrecWith2 sp1       sp2)
-                       ) "TyFamily" p x
-
--------------------------------------------------------------------------------
+$(deriveShow1 ''TyCon)
+#if defined(NEW_FUNCTOR_CLASSES)
+$(deriveShow2 ''TyCon)
+#endif
 
 $(deriveTextShow  ''TyCon)
 $(deriveTextShow1 ''TyCon)
 $(deriveTextShow2 ''TyCon)
 
-#if MIN_VERSION_template_haskell(2,7,0)
-$(deriveTextShow  'TyFamily)
-$(deriveTextShow1 'TyFamily)
-$(deriveTextShow2 'TyFamily)
-#endif
-
 #if __GLASGOW_HASKELL__ < 706
 $(Generics.deriveMeta           ''TyCon)
 $(Generics.deriveRepresentable1 ''TyCon)
@@ -143,6 +124,17 @@ $(Generics.deriveRepresentable0 ''TyCon)
 #endif
 
 #if MIN_VERSION_template_haskell(2,7,0)
+# if !defined(NEW_FUNCTOR_CLASSES)
+$(deriveShow1 'TyFamily)
+# else
+$(deriveShow1 'TyFamily)
+$(deriveShow2 'TyFamily)
+# endif
+
+$(deriveTextShow  'TyFamily)
+$(deriveTextShow1 'TyFamily)
+$(deriveTextShow2 'TyFamily)
+
 # if !defined(__LANGUAGE_DERIVE_GENERIC1__)
 $(Generics.deriveMeta           'TyFamily)
 $(Generics.deriveRepresentable1 'TyFamily)
