@@ -18,73 +18,6 @@ import Prelude.Compat
 
 import Test.QuickCheck (Arbitrary(..))
 
-#if !(MIN_VERSION_QuickCheck(2,9,0))
-instance ( Arbitrary a
-         , Arbitrary b
-         , Arbitrary c
-         , Arbitrary d
-         , Arbitrary e
-         , Arbitrary f
-         ) => Arbitrary (a, b, c, d, e, f) where
-    arbitrary = (,,,,,)
-        <$> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary
-        <*> arbitrary
-
-instance ( Arbitrary a
-         , Arbitrary b
-         , Arbitrary c
-         , Arbitrary d
-         , Arbitrary e
-         , Arbitrary f
-         , Arbitrary g
-         ) => Arbitrary (a, b, c, d, e, f, g) where
-    arbitrary = (,,,,,,)
-        <$> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary
-        <*> arbitrary <*> arbitrary
-
-instance ( Arbitrary a
-         , Arbitrary b
-         , Arbitrary c
-         , Arbitrary d
-         , Arbitrary e
-         , Arbitrary f
-         , Arbitrary g
-         , Arbitrary h
-         ) => Arbitrary (a, b, c, d, e, f, g, h) where
-    arbitrary = (,,,,,,,)
-        <$> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary
-        <*> arbitrary <*> arbitrary <*> arbitrary
-
-instance ( Arbitrary a
-         , Arbitrary b
-         , Arbitrary c
-         , Arbitrary d
-         , Arbitrary e
-         , Arbitrary f
-         , Arbitrary g
-         , Arbitrary h
-         , Arbitrary i
-         ) => Arbitrary (a, b, c, d, e, f, g, h, i) where
-    arbitrary = (,,,,,,,,)
-        <$> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary
-        <*> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary
-
-instance ( Arbitrary a
-         , Arbitrary b
-         , Arbitrary c
-         , Arbitrary d
-         , Arbitrary e
-         , Arbitrary f
-         , Arbitrary g
-         , Arbitrary h
-         , Arbitrary i
-         , Arbitrary j
-         ) => Arbitrary (a, b, c, d, e, f, g, h, i, j) where
-    arbitrary = (,,,,,,,,,)
-        <$> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary
-        <*> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary
-#endif
-
 instance ( Arbitrary a
          , Arbitrary b
          , Arbitrary c
