@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP                        #-}
 {-# LANGUAGE FlexibleContexts           #-}
 {-# LANGUAGE FlexibleInstances          #-}
 {-# LANGUAGE GeneralizedNewtypeDeriving #-}
@@ -9,7 +10,7 @@
 
 {-|
 Module:      Instances.GHC.Generics
-Copyright:   (C) 2014-2015 Ryan Scott
+Copyright:   (C) 2014-2016 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -19,6 +20,8 @@ Portability: GHC
 -}
 module Instances.GHC.Generics () where
 
+import Data.Orphans ()
+
 import Generics.Deriving.Base
 
 import GHC.Exts (Char(C#), Double(D#), Float(F#), Int(I#), Word(W#))
@@ -46,13 +49,22 @@ instance (Arbitrary (f p), Arbitrary (g p)) => Arbitrary ((f :*: g) p) where
 instance Arbitrary Fixity where
     arbitrary = oneof [pure Prefix, Infix <$> arbitrary <*> arbitrary]
 
-deriving instance Bounded Associativity
-deriving instance Enum Associativity
 instance Arbitrary Associativity where
     arbitrary = arbitraryBoundedEnum
 
+#if MIN_VERSION_base(4,9,0)
+instance Arbitrary SourceUnpackedness where
+    arbitrary = arbitraryBoundedEnum
+
+instance Arbitrary SourceStrictness where
+    arbitrary = arbitraryBoundedEnum
+
+instance Arbitrary DecidedStrictness where
+    arbitrary = arbitraryBoundedEnum
+#else
 instance Arbitrary Arity where
     arbitrary = oneof [pure NoArity, Arity <$> arbitrary]
+#endif
 
 instance Arbitrary (UChar p) where
     arbitrary = do
