@@ -3,7 +3,7 @@
 
 {-|
 Module:      Instances.GHC.Stats
-Copyright:   (C) 2014-2015 Ryan Scott
+Copyright:   (C) 2014-2016 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -28,4 +28,7 @@ instance Arbitrary GCStats where
                         <*> arbitrary <*> arbitrary <*> arbitrary
                         <*> arbitrary <*> arbitrary <*> arbitrary
                         <*> arbitrary <*> arbitrary <*> arbitrary
+# if __GLASGOW_HASKELL__ >= 801
+                        <*> arbitrary
+# endif
 #endif
