@@ -2,7 +2,7 @@
 
 {-|
 Module:      Spec.Control.ExceptionSpec
-Copyright:   (C) 2014-2015 Ryan Scott
+Copyright:   (C) 2014-2016 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -53,6 +53,10 @@ spec = parallel . describe "TextShow.Control.Exception" $ do
 #if MIN_VERSION_base(4,8,0)
     describe "AllocationLimitExceeded" $
         prop "TextShow instance" (prop_matchesTextShow :: Int -> AllocationLimitExceeded -> Bool)
+#endif
+#if MIN_VERSION_base(4,9,0)
+    describe "TypeError" $
+        prop "TextShow instance" (prop_matchesTextShow :: Int -> TypeError -> Bool)
 #endif
     describe "Deadlock" $
         prop "TextShow instance" (prop_matchesTextShow :: Int -> Deadlock -> Bool)
