@@ -2,7 +2,7 @@
 
 {-|
 Module:      Spec.Derived.RankNTypesSpec
-Copyright:   (C) 2014-2015 Ryan Scott
+Copyright:   (C) 2014-2016 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -12,9 +12,9 @@ Portability: GHC
 -}
 module Spec.Derived.RankNTypesSpec (main, spec) where
 
-import Derived.Records
+import Derived.RankNTypes
 
-import Spec.Utils (prop_matchesTextShow2)
+import Spec.Utils (prop_matchesTextShow1)
 
 import Test.Hspec (Spec, describe, hspec, parallel)
 import Test.Hspec.QuickCheck (prop)
@@ -25,8 +25,8 @@ main = hspec spec
 spec :: Spec
 spec = parallel $ do
     describe "TyCon Int Int" $
-        prop "TextShow2 instance" (prop_matchesTextShow2 :: Int -> TyCon Int Int -> Bool)
+        prop "TextShow1 instance" (prop_matchesTextShow1 :: Int -> TyCon Int Int -> Bool)
 #if MIN_VERSION_template_haskell(2,7,0)
     describe "TyFamily Int Int" $
-        prop "TextShow2 instance" (prop_matchesTextShow2 :: Int -> TyFamily Int Int -> Bool)
+        prop "TextShow2 instance" (prop_matchesTextShow1 :: Int -> TyFamily Int Int -> Bool)
 #endif
