@@ -12,8 +12,7 @@ Portability: GHC
 Testing-related utility functions.
 -}
 module Spec.Utils (
-      ioProperty
-    , prop_matchesTextShow
+      prop_matchesTextShow
     , prop_matchesTextShow1
 #if defined(NEW_FUNCTOR_CLASSES)
     , prop_matchesTextShow2
@@ -26,13 +25,6 @@ import           Data.Functor.Classes (Show1, showsPrec1)
 
 import           Generics.Deriving.Base
 
-#if MIN_VERSION_QuickCheck(2,7,0)
-import qualified Test.QuickCheck as QC (ioProperty)
-#else
-import           Test.QuickCheck (morallyDubiousIOProperty)
-#endif
-import           Test.QuickCheck (Property, Testable)
-
 import           TextShow (TextShow(..), TextShow1(..), showbPrec1, fromString)
 import           TextShow.Generic
 
@@ -41,13 +33,6 @@ import           Data.Functor.Classes (Show2, showsPrec2)
 import           TextShow (TextShow2(..), showbPrec2)
 #endif
 
-ioProperty :: Testable prop => IO prop -> Property
-#if MIN_VERSION_QuickCheck(2,7,0)
-ioProperty = QC.ioProperty
-#else
-ioProperty = morallyDubiousIOProperty
-#endif
-
 -- | Verifies that a type's 'Show' instances coincide for both 'String's and 'Text',
 -- irrespective of precedence.
 prop_matchesTextShow :: (Show a, TextShow a) => Int -> a -> Bool
